@@ -1,5 +1,5 @@
-package Directory::Scratch; # git description: v0.16-5-g2428a09
-$Directory::Scratch::VERSION = '0.17';
+package Directory::Scratch; # git description: v0.17-3-ga9b3e32
+$Directory::Scratch::VERSION = '0.18';
 # see POD after __END__.
 
 use warnings;
@@ -8,7 +8,7 @@ use Carp;
 use File::Temp;
 use File::Copy;
 use Path::Class qw(dir file);
-use Path::Tiny;
+use Path::Tiny 0.060;
 use File::Spec;
 use File::stat (); # no imports
 
@@ -430,7 +430,7 @@ Directory::Scratch - (DEPRECATED) Easy-to-use self-cleaning scratch space
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DEPRECATION NOTICE
 
